@@ -86,10 +86,10 @@ class CourseSync(BaseSync):
     def extract_course(self):
         double_number_map = self.get_double_map()
         today, last_day = self.get_date_range()
-        today, last_day = "2020-11-02", "2020-11-08"
+        # today, last_day = "2020-11-02", "2020-11-08"
         sql = "SELECT id, coursename, sectionid, classroomid, coursedate, weekday, userid, isteacher, deptname, outid " \
               "FROM mid_attendschedule " \
-              "WHERE updateflag!='3' and coursedate > '{}' and coursedate <= '{}' and deptname!='学生' " \
+              "WHERE updateflag!='3' and coursedate > '{}' and coursedate <= '{}' " \
               "ORDER BY weekday".format(today, last_day)
         self.cur.execute(sql)
         rows = self.cur.fetchall()
@@ -110,6 +110,8 @@ class CourseSync(BaseSync):
                 continue
             # ori_classroom_number = self.classroom_map.get(str(classroom_id))
             ori_classroom_number = str(classroom_id)
+            if ori_classroom_number == '11425':
+                print("1")
             classroom_numbers = double_number_map.get(ori_classroom_number, [ori_classroom_number])
             for classroom_number in classroom_numbers:
                 # 检测教室是否在其他作息课表出现,如果出现，就跳过
@@ -171,7 +173,7 @@ class CourseSync(BaseSync):
             course_table.classrooms_num = list(self.classroom_set[course_table_name])
             course_table.sections_num = list(self.class_set[course_table_name])
             course_table.courses = list(self.course_container[course_table_name])
-            print(">>> CREATE_COURSE_TABLE")
+            print(">>> CREATE_COURSE_TABLE': {}".format(course_table_name))
             logger.info(">>> CREATE_COURSE_TABLE")
             self.client.create_course_table(self.school_id, course_table, is_active=True)
         self.client.active_semester(self.school_id, self.semester, delete_other=True)
